#
# spec file for package potrace
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           potrace
Version:        1.14
Release:        11.3
Summary:        Utility for Tracing a Bitmap to Scalable Outline Image
License:        GPL-2.0+
Group:          Productivity/Graphics/Convertors
Url:            http://potrace.sourceforge.net/
Source:         http://potrace.sourceforge.net/download/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  zlib-devel
Provides:       bitmap_tracing
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Potrace is a utility for tracing a bitmap, which means, transforming a
bitmap into a smooth, scalable image.  The input is a bitmap (PBM, PGM,
PPM, or BMP), and the default output is one of several vector file
formats.  A typical use is to create EPS files from scanned data, such
as company or university logos, handwritten notes, etc. The resulting
image is not "jaggy" like a bitmap, but smooth. It can then be rendered
at any resolution.

%package -n libpotrace0
Summary:        Library for Tracing a Bitmap to Scalable Outline Image
Group:          System/Libraries

%description -n libpotrace0
Potrace is a utility for tracing a bitmap, which means, transforming a
bitmap into a smooth, scalable image.  The input is a bitmap (PBM, PGM,
PPM, or BMP), and the default output is one of several vector file
formats.  A typical use is to create EPS files from scanned data, such
as company or university logos, handwritten notes, etc. The resulting
image is not "jaggy" like a bitmap, but smooth. It can then be rendered
at any resolution.

%package devel
Summary:        Library Development Files for Tracing a Bitmap to Scalable Outline Image
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}

%description devel
Potrace is a utility for tracing a bitmap, which means, transforming a
bitmap into a smooth, scalable image.  The input is a bitmap (PBM, PGM,
PPM, or BMP), and the default output is one of several vector file
formats.  A typical use is to create EPS files from scanned data, such
as company or university logos, handwritten notes, etc. The resulting
image is not "jaggy" like a bitmap, but smooth. It can then be rendered
at any resolution.

%prep
%setup -q

%build
%configure\
	--docdir=%{_docdir}/%{name}\
	--with-libpotrace\
	--disable-static
make  %{?_smp_mflags}

%install
%if %suse_version > 1110
%make_install
%else
%makeinstall
%endif
cp -a AUTHORS ChangeLog COPYING NEWS README %{buildroot}%{_docdir}/%{name}/
rm %{buildroot}%{_libdir}/*.*a

%clean
rm -rf %{buildroot}

%post -n libpotrace0 -p /sbin/ldconfig

%postun -n libpotrace0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/*
%doc %{_docdir}/%{name}
%doc %{_mandir}/man?/*.*

%files -n libpotrace0
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/*.h
%{_libdir}/*.so

%changelog
* Tue Feb 28 2017 sbrabec@suse.com
- Update to version 1.14:
  * Bugs triggered by malformed BMP files have been fixed,
    including CVE-2016-8685 (bsc#1005026) and CVE-2016-8686.
  * Error reporting has been improved.
  * The image size is now truncated when the bitmap data ends
    prematurely.
  * It is now possible to use negative dy in bitmap data.
* Fri Oct 23 2015 sbrabec@suse.com
- Update to version 1.13:
  * Some critical bugs in the processing of BMP files were fixed
    (bsc#951760).
  * Portability was improved for C99 and for MSVC++.
* Thu Apr  2 2015 sbrabec@suse.cz
- Update to version 1.12:
  * fix memory overflow bug triggered by very large bitmaps
    (bsc#924904, CVE-2013-7437)
  * minor fixes
* Wed Feb 20 2013 sbrabec@suse.cz
- Update to version 1.11:
  * A GeoJSON backend was added.
  * Support for bitfields in the BMP format was added.
  * A minor change was made to the behavior of the alphamax
    parameter; a value of 0 now gives a true polygon.
- Build shared libpotrace.
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sat Aug 20 2011 mrdocs@opensuse.org
- update to 1.10
  + added --tight option
  + backends: simplified dimension calculations
  + eps backend: prevent integer overflow in bounding box.
  + disallow resolution of 0 dpi.
  + man page: added BACKEND TYPES section
  + fixed default scaling at 72dpi for 	variable-sized backends
  + new gimppath backend produces SVG output
  + suitable for current versions of Gimp.
  + added a --flat option for the SVG backend.
  + test suite: renamed *.out files to prevent make's
  + built-in implicit rules from accidentally overwriting them.
  + added DXF backend. Thanks to Jonas Benedett Dorr for testing.
  + use high resolution bounding box in EPS, PDF, and SVG backends
  + autoconf: CADD can now be given at compile time
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Wed Jan 12 2011 mrdocs@opensuse.org
-Update to 1.9
  +the XFig and EPS backends were improved, and a fixed pagesize PDF backend was added;
  + support for BMP version 4 and version 5 files, as well as top-down BMP files, was added;
  + you'll see minor speed improvements to Potrace and major speed improvements to mkbitmap;
  + a Gaussian blur option was added to mkbitmap;
  + a change in the build sustem: libtool is now used to build and optionally install the Potrace library;
  + an optional simplified progress bar was added for dumb terminals;
  + this release also contains some portability improvements, cross-compilation improvements, and minor bug fixes.
- run spec cleaner on the spec file and remove redundant changes from spec
- drop xfig-patch as it is upstream now
* Thu Jul 26 2007 sbrabec@suse.cz
- Updated to version 1.8:
  * minor bugfixes and portability improvements
  * rotation is now implemented in the PDF backend
* Thu Mar 29 2007 rguenther@suse.de
- add zlib-devel BuildRequires.
* Wed Nov 15 2006 jw@suse.de
- replaced wrong_allocation.patch by official
  io.patch -- more bugs fixed.
* Wed Jul 19 2006 pnemec@suse.cz
- fixed wrong memory allocation in potracelib.c
  (added potrace-wrong_allocation.patch)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Mar  9 2005 nadvornik@suse.cz
- Updated to version 1.7:
  * A bug in the progress bar code, which caused arithmetic
    exceptions on some 64-bit architectures, has been fixed.
* Mon Feb 28 2005 sbrabec@suse.cz
- Updated to version 1.6.
* Thu Jan  6 2005 sbrabec@suse.cz
- Provide bitmap_tracing virtual.
* Fri Aug 27 2004 sbrabec@suse.cz
- Updated to version 1.5 (with LZW support).
* Mon Mar  8 2004 sbrabec@suse.cz
- Updated to version 1.4.
* Thu Feb  5 2004 sbrabec@suse.cz
- Added speed optimization patch from author.
* Thu Jan 15 2004 sbrabec@suse.cz
- Updated to version 1.3.
* Wed Aug 13 2003 sbrabec@suse.cz
- Initial version 1.0.
